==> siga.copmoz.ac.mz_02_56.zip: siga.copmoz.ac.mz/storage/framework/views/74be5e1e5297777e2905deecff9a1022.php <==
<title><?php echo e(config('chatify.name')); ?></title>


<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="id" content="<?php echo e($channel_id); ?>">
<meta name="messenger-color" content="<?php echo e($messengerColor); ?>">
<meta name="messenger-theme" content="<?php echo e($dark_mode); ?>">
<meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
<?php if(Auth::guard('web')->check()): ?>
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-user="<?php echo e(Auth::guard('web')->id()); ?>">
<?php elseif(Auth::guard('admin')->check()): ?>
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.adminroutes.prefix')); ?>" data-user="<?php echo e(Auth::guard('admin')->id()); ?>">
<?php else: ?>
    
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-user="0">
<?php endif; ?>

<script
  src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="<?php echo e(asset('js/chatify/font.awesome.min.js')); ?>"></script>
<script src="<?php echo e(asset('js/chatify/autosize.js')); ?>"></script>
<!--<<script src="<?php echo e(asset('js/app.js')); ?>"></script>-->
<script src='https://unpkg.com/nprogress@0.2.0/nprogress.js'></script>


<link rel='stylesheet' href='https://unpkg.com/nprogress@0.2.0/nprogress.css'/>
<link href="<?php echo e(asset('css/chatify/style.css')); ?>" rel="stylesheet" />
<link href="<?php echo e(asset('css/chatify/'.$dark_mode.'.mode.css')); ?>" rel="stylesheet" />
<!--<link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet" /> -->


<style>
    :root {
        --primary-color: <?php echo e($messengerColor); ?>;
    }
</style>

<!-- <title><?php echo e(config('chatify.name')); ?></title>


<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="id" content="<?php echo e($channel_id); ?>">
<meta name="messenger-color" content="<?php echo e($messengerColor); ?>">
<meta name="messenger-theme" content="<?php echo e($dark_mode); ?>">
<meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">


<?php if(Auth::guard('web')->check()): ?>
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-user="<?php echo e(Auth::guard('web')->id()); ?>">
<?php elseif(Auth::guard('admin')->check()): ?>
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-user="<?php echo e(Auth::guard('admin')->id()); ?>">
<?php else: ?>
    
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-user="0">
<?php endif; ?>


<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="<?php echo e(asset('js/chatify/font.awesome.min.js')); ?>"></script>
<script src="<?php echo e(asset('js/chatify/autosize.js')); ?>"></script>
<script src="<?php echo e(asset('js/app.js')); ?>"></script>
<script src='https://unpkg.com/nprogress@0.2.0/nprogress.js'></script>


<link rel='stylesheet' href='https://unpkg.com/nprogress@0.2.0/nprogress.css'/>
<link href="<?php echo e(asset('css/chatify/style.css')); ?>" rel="stylesheet" />
<link href="<?php echo e(asset('css/chatify/'.$dark_mode.'.mode.css')); ?>" rel="stylesheet" />
<link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet" />


<style>
    :root {
        --primary-color: <?php echo e($messengerColor); ?>;
    }
</style> -->
<?php /**PATH /home/salum3x/public_html/siga.copmoz.ac.mz/resources/views/vendor/Chatify/layouts/headLinks.blade.php ENDPATH**/ ?>

==> siga.copmoz.ac.mz_19_10_2025.zip: siga.copmoz.ac.mz/storage/framework/views/74be5e1e5297777e2905deecff9a1022.php <==
<title><?php echo e(config('chatify.name')); ?></title>


<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="channel_id" content="<?php echo e($channel_id); ?>">
<meta name="messenger-color" content="<?php echo e($messengerColor); ?>">
<meta name="messenger-theme" content="<?php echo e($dark_mode); ?>">
<meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">
<?php if(Auth::guard('web')->check()): ?>
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-auth-user="<?php echo e(Auth::guard('web')->id()); ?>">
<?php elseif(Auth::guard('admin')->check()): ?>
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.adminroutes.prefix')); ?>" data-auth-user="<?php echo e(Auth::guard('admin')->id()); ?>">
<?php else: ?>
    
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-auth-user="0">
<?php endif; ?>

<script
  src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="<?php echo e(asset('js/chatify/font.awesome.min.js')); ?>"></script>
<script src="<?php echo e(asset('js/chatify/autosize.js')); ?>"></script>
<!--<<script src="<?php echo e(asset('js/app.js')); ?>"></script>-->
<script src='https://unpkg.com/nprogress@0.2.0/nprogress.js'></script>


<link rel='stylesheet' href='https://unpkg.com/nprogress@0.2.0/nprogress.css'/>
<link href="<?php echo e(asset('css/chatify/style.css')); ?>?upfdfge" rel="stylesheet" />
<link href="<?php echo e(asset('css/chatify/'.$dark_mode.'.mode.css')); ?>?upfdfge" rel="stylesheet" />
<!--<link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet" /> -->


<style>
    :root {
        --primary-color: <?php echo e($messengerColor); ?>;
    }
</style>

<!-- <title><?php echo e(config('chatify.name')); ?></title>


<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="id" content="<?php echo e($channel_id); ?>">
<meta name="messenger-color" content="<?php echo e($messengerColor); ?>">
<meta name="messenger-theme" content="<?php echo e($dark_mode); ?>">
<meta name="csrf-token" content="<?php echo e(csrf_token()); ?>">


<?php if(Auth::guard('web')->check()): ?>
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-user="<?php echo e(Auth::guard('web')->id()); ?>">
<?php elseif(Auth::guard('admin')->check()): ?>
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-user="<?php echo e(Auth::guard('admin')->id()); ?>">
<?php else: ?>
    
    <meta name="url" content="<?php echo e(url('').'/'.config('chatify.routes.prefix')); ?>" data-user="0">
<?php endif; ?>


<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="<?php echo e(asset('js/chatify/font.awesome.min.js')); ?>"></script>
<script src="<?php echo e(asset('js/chatify/autosize.js')); ?>"></script>
<script src="<?php echo e(asset('js/app.js')); ?>"></script>
<script src='https://unpkg.com/nprogress@0.2.0/nprogress.js'></script>


<link rel='stylesheet' href='https://unpkg.com/nprogress@0.2.0/nprogress.css'/>
<link href="<?php echo e(asset('css/chatify/style.css')); ?>" rel="stylesheet" />
<link href="<?php echo e(asset('css/chatify/'.$dark_mode.'.mode.css')); ?>" rel="stylesheet" />
<link href="<?php echo e(asset('css/app.css')); ?>" rel="stylesheet" />


<style>
    :root {
        --primary-color: <?php echo e($messengerColor); ?>;
    }
</style> -->
<?php /**PATH /home/salum3x/public_html/siga.copmoz.ac.mz/resources/views/vendor/Chatify/layouts/headLinks.blade.php ENDPATH**/ ?>
